==> mobiusft-0.5.31.tar.bz2: mobiusft-0.5.31/src/python/mobius/disk/func_new_disk_from_reader.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//!\brief  C++ API module wrapper
//!\author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <Python.h>
#include "disk_reader.h"
#include "api_reader.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//!\brief function new_disk_from_reader
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_new_disk_from_reader (PyObject *, PyObject *args)
{
  // parse arguments
  int arg_sector_size = 512;
  PyObject *arg_reader;

  if (!PyArg_ParseTuple (args, "O!|i", &api_reader_t, &arg_reader, &arg_sector_size))
    return nullptr;

  mobius::io::reader *reader_p = ((api_reader_o *) arg_reader)->obj;

  // create disk
  disk_disk_reader_o *ret = (disk_disk_reader_o *) _PyObject_New (&disk_disk_reader_t);

  if (ret == nullptr)
    return nullptr;

  auto disk = mobius::disk::new_disk_from_reader (*reader_p, arg_sector_size);
  ret->obj = new mobius::disk::disk_reader (disk);

  // return object
  return (PyObject *) ret;
}

==> mobiusft-1.17.tar.bz2: mobiusft-1.17/src/python/mobius/disk/func_new_disk_from_reader.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <pymobius.h>
#include "disk_reader.h"
#include "io/reader.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief new_disk_from_reader function
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_new_disk_from_reader (PyObject *, PyObject *args)
{
  // parse arguments
  int arg_sector_size = 512;
  PyObject *arg_reader;

  if (!PyArg_ParseTuple (args, "O!|i", &io_reader_t, &arg_reader, &arg_sector_size))
    return nullptr;

  mobius::io::reader *reader_p = ((io_reader_o *) arg_reader)->obj;

  // create disk
  disk_disk_reader_o *ret = (disk_disk_reader_o *) _PyObject_New (&disk_disk_reader_t);

  if (ret == nullptr)
    return nullptr;

  auto disk = mobius::disk::new_disk_from_reader (*reader_p, arg_sector_size);
  ret->obj = new mobius::disk::disk_reader (disk);

  // return object
  return (PyObject *) ret;
}
